Welcome to mirror list, hosted at ThFree Co, Russian Federation.

cygwin.com/git/newlib-cygwin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCorinna Vinschen <corinna@vinschen.de>2009-03-26 13:26:57 +0300
committerCorinna Vinschen <corinna@vinschen.de>2009-03-26 13:26:57 +0300
commitfa0853e16847e18e75a182949879b3a090a2580d (patch)
tree241882eef1fd672d7d6f93373265f1ee4db3476f /winsup/cygwin/strfuncs.cc
parente916d8ec8647e988ed5e0d9cb0e7f3a66100456b (diff)
* strfuncs.cc (__set_charset_from_codepage): Revert to translating
codepage 936 to "GBK".
Diffstat (limited to 'winsup/cygwin/strfuncs.cc')
-rw-r--r--winsup/cygwin/strfuncs.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/winsup/cygwin/strfuncs.cc b/winsup/cygwin/strfuncs.cc
index 03e14c015..bb3682225 100644
--- a/winsup/cygwin/strfuncs.cc
+++ b/winsup/cygwin/strfuncs.cc
@@ -28,7 +28,7 @@ details. */
implementation of the base functions for the conversion using
the MulitByteToWideChar/WideCharToMultiByte functions. */
/* GB2312, eucKR, and Big5 conversions are not available so far in newlib. */
static int
__db_wctomb (struct _reent *r, char *s, wchar_t wchar, UINT cp)
@@ -253,7 +253,7 @@ __set_charset_from_codepage (UINT cp, char *charset)
strcpy (charset, "SJIS");
return __sjis_mbtowc;
case 936:
- strcpy (charset, "GB2312");
+ strcpy (charset, "GBK");
return __gbk_mbtowc;
case 949:
case 51949:
@@ -28,7 +28,7 @@ details. */
implementation of the base functions for the conversion using
the MulitByteToWideChar/WideCharToMultiByte functions. */
-/* GB2312, eucKR, and Big5 conversions are not available so far in newlib. */
+/* GBK, eucKR, and Big5 conversions are not available so far in newlib. */
static int
__db_wctomb (struct _reent *r, char *s, wchar_t wchar, UINT cp)